pub struct Payload {
pub asset_path: String,
pub prim_path: Path,
pub layer_offset: Option<LayerOffset>,
}Expand description
Represents a payload and all its meta data.
A payload represents a prim reference to an external layer. A payload is similar to a prim reference (see SdfReference) with the major difference that payloads are explicitly loaded by the user.
Unloaded payloads represent a boundary that lazy composition and system behaviors will not traverse across, providing a user-visible way to manage the working set of the scene.
Fields
asset_path: StringThe asset path to the external layer.
prim_path: PathThe root prim path to the referenced prim in the external layer.
layer_offset: Option<LayerOffset>The layer offset to transform time.