TextReader

Struct TextReader 

pub struct TextReader { /* private fields */ }
Reader for USD’s ASCII text format (.usda).

Implementations

Source

impl TextReader

pub fn read(path: impl AsRef<Path>) -> Result<Self>

Read a file on disk.

pub fn from_data(data: HashMap<Path, Spec>) -> Self

Create from parsed data.

pub fn iter(&self) -> impl Iterator<Item = (&Path, &Spec)>

Returns an iterator over all specs in the reader.

pub fn prim_children(&self, path: &Path) -> Vec<Path>

Returns the child prim paths for a given prim by reading its primChildren field.

pub fn attribute_value<T>(&self, path: &Path) -> Option<T>
where T: TryFrom<Value>,

Returns the value of an attribute if it exists and matches the requested type. This looks for the default field on the property spec at the given path.

pub fn prim_attribute_value<T>( &self, prim_path: &Path, attr_name: &str, ) -> Option<T>
where T: TryFrom<Value>,

Returns an attribute value directly from a prim path and attribute name.