pub struct TextReader { /* private fields */ }Expand description
Reader for USD’s ASCII text format (.usda).
Implementations
Sourceimpl TextReader
impl TextReader
Sourcepub fn iter(&self) -> impl Iterator<Item = (&Path, &Spec)>
pub fn iter(&self) -> impl Iterator<Item = (&Path, &Spec)>
Returns an iterator over all specs in the reader.
Sourcepub fn prim_children(&self, path: &Path) -> Vec<Path>
pub fn prim_children(&self, path: &Path) -> Vec<Path>
Returns the child prim paths for a given prim by reading its primChildren field.
Sourcepub fn attribute_value<T>(&self, path: &Path) -> Option<T>
pub fn attribute_value<T>(&self, path: &Path) -> Option<T>
Returns the value of an attribute if it exists and matches the requested type.
This looks for the default field on the property spec at the given path.